@@ -5,6 +5,7 @@ import (
 	"context"
 	_ "embed"
 	"path/filepath"
+	"strings"
 	"syscall"
 
 	"github.com/spf13/cobra"
@@ -33,6 +34,11 @@ var (
 //go:embed docker.md
 var longHelp string
 
+// help returns the help string cleaned up to simplify appending
+func help() string {
+	return strings.TrimSpace(longHelp) + "\n\n"
+}
+
 func init() {
 	cmdFlags := Command.Flags()
 	// Add command specific flags
@@ -50,7 +56,7 @@ func init() {
 var Command = &cobra.Command{
 	Use:   "docker",
 	Short: `Serve any remote on docker's volume plugin API.`,
-	Long:  longHelp + vfs.Help,
+	Long:  help() + vfs.Help(),
 	Annotations: map[string]string{
 		"versionIntroduced": "v1.56",
 		"groups":            "Filter",
